#
# spec file for package gobby
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _versioned_name gobby-0.5
Name:           gobby
Version:        0.5.1+20180826.d16519e
Release:        bp154.1.62
Summary:        Collaborative editor (Infinote protocol)
License:        GPL-2.0-or-later AND ISC
Group:          Productivity/Other
URL:            http://gobby.0x539.de/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  gnome-doc-utils-devel
# For directory ownership:
BuildRequires:  gnome-themes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(libgsasl)
BuildRequires:  pkgconfig(libinfinity-0.7)
BuildRequires:  pkgconfig(libxml++-2.6)
Requires(post): update-alternatives
Requires(postun):update-alternatives
%if 0%{?favor_gtk2}
BuildRequires:  pkgconfig(gtkmm-2.4)
BuildRequires:  pkgconfig(gtksourceview-2.0)
%else
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
%endif

%description
This is a collaborative editor, which means that it provides
the possibility to edit files simultaneously with other users over
a network. It supports multiple documents in one session.

This version of Gobby uses the Infinote protocol.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
    --disable-scrollkeeper \
    --with-gnome \
%if 0%{?favor_gtk2}
    --without-gtk3
%else
    --with-gtk3
%endif
%make_build

%install
%make_install
%find_lang gobby05 %{?no_lang_C}
# For documentation. It's not versioned, but gobby 0.4 doesn't have such files,
# so there's no conflict.
# %%find_lang gobby %%{?no_lang_C} gobby05.lang
%suse_update_desktop_file -N "Gobby" -G "Collaborative Editor" %{_versioned_name} X-SuSE-Core-Internet
%fdupes %{buildroot}

%if 0%{?suse_version} < 1330
%post
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post HighContrastLargePrint
%icon_theme_cache_post HighContrastLargePrintInverse

%postun
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun HighContrastLargePrint
%icon_theme_cache_postun HighContrastLargePrintInverse
%endif

%files
%license COPYING
%doc AUTHORS
%dir %{_datadir}/help/
%doc %{_datadir}/help/C/%{name}
# %%dir %%{_datadir}/omf/
# %%dir %%{_datadir}/omf/%%{name}/
# %%doc %%{_datadir}/omf/%%{name}/%%{name}-C.omf
%{_bindir}/%{_versioned_name}
%{_datadir}/%{_versioned_name}
%{_datadir}/applications/%{_versioned_name}.desktop
%{_datadir}/icons/*/*/apps/%{_versioned_name}.*
%{_mandir}/man1/*%{ext_man}
%{_datadir}/appdata/gobby-0.5.appdata.xml
%{_datadir}/glib-2.0/schemas/de.0x539.gobby.gschema.xml
# FIXME: gnome-themes does not provide excluded directories yet.
%exclude %{_datadir}/icons/HighContrast*/scalable/*

%files lang -f gobby05.lang

%changelog
* Fri Apr 16 2021 Dirk Müller <dmueller@suse.com>
- stop owning dirs provided by filesystem rpm (bsc#1184786)
* Fri Mar 20 2020 mcepl@suse.com
- Update to version 0.5.1+20180826.d16519e:
  * Correct "Remeber" → "Remember" arrow.
  * Make yelp conditional on --enable-docs (default=yes).
  * help/Makefile.am: fix tab/spaces inconsistency
  * Update CI build environment to include yelp-tools.
  * Use yelp-tools instead of gtk-doc-utils.
  * Update ca.po
  * Use https in README
  * Add suggested desktop category
  * Fix include directives to just include <gtksourceview/gtksource.h>.
  * Add newly translatable units to POTFILES.in and drop non-existing ones.
  * Set AC_CONFIG_AUX_DIR to the top-level source directory.
  * Fix some compile warnings
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Sep 18 2017 dimstar@opensuse.org
- Drop update-alternative usage: we only have one version of gobby
  available and there is no merit in the complexity anymore
  (obsoletes boo#994272).
- Disable current post/postun scripts on suse_version >= 1330: the
  desktop_database and icon_theme scriptlets have been obsoleted by
  respective file triggers.
* Mon Aug 28 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(unique-1.0) BuildRequires.
* Thu Aug 24 2017 zaitor@opensuse.org
- Change License to "ISC AND GPL-2.0+" following legal review.
- Change Group to Productivity/Other.
* Thu Jun 29 2017 jengelh@inai.de
- Trim irrelevant parts from description.
* Thu Jun  8 2017 zaitor@opensuse.org
- Update to version 0.5.1+20170204.e5c2d14:
  + Add C++11 macros into m4/ to fix the travis build.
  + Remove no longer used configure flags from travis config.
  + Fix typo in header guard.
  + Replace margin start/end with left/right.
  + Add missing giomm/menu.h include to
    browser-context-commands.cpp.
  + Fix possible crash when opening popup menu on browser.
  + Add license title.
  + Fix setting of font preferences.
  + Updated translations.
- Run spec-cleaner.
- Switch to service version git checkout.
- Following the above, add gnome-common BuildRequires and pass
  NOCONFIGUE=1 autogen.sh to configure, bootstrap gitcheckout.
- Replace pkgconfig(libinfinity-0.6) with
  pkgconfig(libinfinity-0.7) BuildRequires following upstream
  changes.
- Drop obsolete posttrans section.
- Drop gobby-add-missing-return.patch: Fixed upstream.
* Sat Oct 11 2014 zaitor@opensuse.org
- Update to version 0.5.0:
  + Allow to run a server within the Gobby process; infinoted is no
    longer required to connect to other people.
  + Added support for user accounts and different permissions for
    different accounts.
  + Added limited support for chat nodes in the document tree.
  + Added an option to set the opacity with which user colors are
    shown behind the text.
  + Added Fullscreen option and Ctrl++ and Ctrl+- shortcuts to
    increase/decrease the font size.
  + Gobby can open infinote://XXX URIs given on the command line to
    directly open one or more documents at startup.
- Replace pkgconfig(libinfinity-0.5) for pkgconfig(libinfinity-0.6)
  following upstream changes.
- Drop gobby-glibmm-2_31.patch and gobby-gtksourceview38.patch:
  Fixed upstream.
- Add gobby-add-missing-return.patch: Fix a missing return.
* Fri Apr 19 2013 dimstar@opensuse.org
- Add gobby-gtksourceview38.patch: Fix build with gtksourceview 3.8
  that changed to single header includes.
* Tue Apr  9 2013 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of GPL-2.0 "only" code and certainly no indication of
  aggregation
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Thu Feb  9 2012 dimstar@opensuse.org
- Add gobby-glibmm-2_31.patch: Fix build with glibmm 2.31.
* Fri May 27 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: glibmm2-devel, gtkmm2-devel, libinfinity-devel,
    libunique-devel, libxml++-devel.
  + New ones: glibmm-2.4, gtkmm-2.4, libgsasl, libinfinity-0.5,
    libxml++-2.6, unique-1.0.
* Thu Apr 28 2011 dimstar@opensuse.org
- Use favor_gtk2 to switch between gtk2 and gtk3 builds.
- For gtk3 build, add pkgconfig(gtkmm-3.0) and
  pkgconfig(gtksourceview-3.0) BuildRequires.
- Pass -with-gtk3/--without-gtk3 based on favor_gtk2 to configure.
* Tue Apr 26 2011 dimstar@opensuse.org
- Update to version 0.4.94:
  + Show cursors and selections of remote users in the own viewport
    and scrollbar
  + Add a "Disconnect from Server" option to the context menu
  + When double-clicking a user in the user list jump to its
    current cursor position
  + Allow gobby to be built against GTK+ 3
  + Fixed a bug which prevented "Save All" from working.
- Replace gtksourceview-devel BuildRequires with
  pkgconfig(gtksourceview-2.0).
- Drop gobby-fix-finddialog-voidreturn.patch: fixed upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Wed Oct 13 2010 vuntz@opensuse.org
- Do not add wrong categories to gobby.desktop (Office,
  X-SuSE-Core-Office). Add X-SuSE-Core-Internet to make the build
  happy, though.
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 0.4.93:
  + Added IRC-like chat
  + Added functionality to export a document to HTML
  + Sort browser entries
  + Allow selecting multiple files when opening files
  + Allow resetting user colors in a document
  + Added a Connect to Server option to the File menu
  + Undo words instead of individual characters
  + When starting Gobby twice then send commands to an existing
    Gobby (if any) unless the -n command line option is given
  + Added an option to highlight spaces and tabs
- Drop gobby-desktop.patch: fixed upstream.
- Add gnome-doc-utils-devel and libunique-devel BuildRequires.
- Pass --disable-scrollkeeper to configure.
* Mon Dec  7 2009 vuntz@opensuse.org
- Rework the update-alternatives part to be correctly handle
  package upgrades. Note that we need a %%posttrans to work around
  bugs in previously installed packages.
* Wed Aug 19 2009 beineri@opensuse.org
- don't put version number into Name field of .desktop file of
  current version but older version (gobby4 package)
* Sat Jun 13 2009 vuntz@novell.com
- Clean up file list.
- Update gobby-desktop.patch: do not change Name, GenericName,
  Categories there, but with suse_update_desktop_file.
- Remove unneeded BuildRequires: gmp-devel, gnutls-devel,
  libavahi-glib-devel, libglade2-devel, libgnomeprintui-devel,
  libgnomeui-devel, libwnck-devel, libgsasl-devel.
- Remove AutoReqProv: it's default now.
- Add update-alternatives PreReq.and use update-alternatives to
  have non-versioned filenames.
* Thu Apr 30 2009 novell@mirell.de
- Update to version 0.4.92:
  * Support running Gobby on Windows 2000.
  * Added Icons for HCLP and HCLPI icon themes (Bug #413, Patrick Wade).
  * Make sure terminating newline characters are saved correctly
  * Added /etc/ssl/certs/ca-certificates.crt as default trust file, if
    available.
  * Don't mess up saving documents whose first line is empty.
  * Write config files in $XDG_CONFIG_HOME instead of $HOME (Bug #437,
    Cristian Klein).
  * Display colored pencil icons in a document's tab for each user that
    made a change since the document has been viewed the last time
    (Bug #66, Mattis Manzel).
* Fri Feb  6 2009 novell@mirell.de
- Update to version 0.4.91:
  + Keep track of a document's modified state between Undo/Redo
  operations
  + Scroll to Cursor after Cut or Paste
  + Added HCLPI icon of the Gobby Logo (Thanks to Thomas Glatt)
  + Added an Autosave Option in the preferences
  + Remember previous host names in "Direct Connection" entry
  + Added an "Open Location" dialog to open arbitrary URIs
  + Added a tooltip when hovering text, showing the author of that text
- Update to version 0.4.90:
  + Complete rewrite
  + Discards net6 and obby, uses libinfinity now
- Rebase gobby-desktop.patch.
- Add gobby-fix-finddialog-voidreturn.patch.
* Sun Jan 25 2009 vuntz@novell.com
- Sanitize BuildRequires.
- Use %%exclude instead of rm for icon files that we can't use at
  the moment.
* Fri Jan  2 2009 msuman@suse.de
- Update to version 0.4.9:
  + Some fixes improving Gobby's accessibility.
  + Use UTF-8 encoded filenames.
  + Updated translations, translation fixes.
- Re-based gobby-desktop.patch
* Thu Jan  1 2009 msuman@suse.de
- Update to version 0.4.8:
  + Fixes a crash when trying to join sessions withouth the avahi
    daemon being running.
- Dropped this patch:
  + gobby-0.4.4-gcc-43.patch - no longer required.
* Fri Sep 12 2008 maw@suse.de
- Update to version 0.4.7:
  + Some fixes improving Gobby's accessibility
  + Enable IPv6 link-local Zeroconf support
  + Bugfixes:
  * Do not crash when no GtkSourceView languages are installed
  * Do not show hidden GtkSourceView languages to the user as
    they are not supposed to be shown and could lead to crashes
  + Updated translations.
* Thu Apr  3 2008 maw@suse.de
- Require obby >= 0.4.5, not 0.4.6.
* Wed Apr  2 2008 maw@suse.de
- Update to version 0.4.6:
  + Bug fixes
  + Updated translations.
* Thu Nov  8 2007 mauro@suse.de
- Added some fixes for gcc 4.3 and beta.
* Thu Oct 11 2007 sbrabec@suse.cz
- Use binding specific avahi package.
* Mon Sep  3 2007 maw@suse.de
- Build against gtksourceview 1.8 again.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage.
* Fri Aug  3 2007 maw@suse.de
- Update to versino 0.4.4:
  + opens absolute file names passed via command line
  + view is kept when remote ops affect the current position
  + documents can be subscribed by doubleclicking on them in the
    list
  + local files aren't flagged as modified
  + urgency hint is configurable
  + tab bar only shown when more than one doc is being edited
  + find and goto dialogs are focused on invocation
  + prefence option added to subscribe automagically to all docs
    in a session
  + window highlights itself only if the chat window is open
  + zeroconf failures are only printed in the console, not in a
    dialog
  + use GtkSourceView's C API directly
  + document list is now sorted alphabetically
  + Misc. fixes
  + Updated translations
- Build against gtksourceview2
- Add gtksourceview.patch
- Use %%fdupes.
* Thu Jun  7 2007 sbrabec@suse.cz
- Fixed desktop file translation.
- Removed invalid desktop Category "Application" (#254654).
* Tue Jan 30 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Sep 26 2006 wstephenson@suse.de
- Update to version 0.4.1
  * Support encrypted communications
  * Improve text handling
  * Improve change merging algorithm
  * Usability improvements
  * Command subsystem eg /command
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 0.3.1
- Bugfix release to correct a problem regarding copy'n'paste
- applied a patch to eliminate missing return statement warnings
  for bug #203564
* Tue Sep  5 2006 meissner@suse.de
- build with CXXFLAGS=RPM_OPT_FLAGS.
* Sat Feb 18 2006 stbinner@suse.de
- fix gobby-desktop.patch (Name / GenericName)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 lmichnovic@suse.cz
- Update to version 0.3.0 [#144674]
* Wed Jan 18 2006 lmichnovic@suse.cz
- Updated to version 0.3.0rc3
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Nov  4 2005 gekker@suse.de
- Initial import into autobuild, version 0.2.2
